@@ -8,6 +8,7 @@ import types
 import base64
 import shutil
 import struct
+import decimal
 import fnmatch
 import hashlib
 import logging
@@ -145,6 +146,13 @@ def intify(x):
     except (TypeError, ValueError):
         return None
 
+hugectx = decimal.Context(prec=15)
+def hugenum(valu):
+    '''
+    Return a decimal.Decimal with proper precision for use as a synapse hugenum.
+    '''
+    return decimal.Decimal(valu, context=hugectx)
+
 def vertup(vstr):
     '''
     Convert a version string to a tuple.
@@ -156,11 +164,11 @@ def vertup(vstr):
     '''
     return tuple([int(x) for x in vstr.split('.')])
 
-def todo(name, *args, **kwargs):
+def todo(_todoname, *args, **kwargs):
     '''
     Construct and return a todo tuple of (name, args, kwargs).
     '''
-    return (name, args, kwargs)
+    return (_todoname, args, kwargs)
 
 def tuplify(obj):
     '''
