@@ -10,7 +10,7 @@ tldlist.reverse()
 tldcat = '|'.join(tldlist)
 fqdn_re = regex.compile(r'((?:[a-z0-9_-]{1,63}\.){1,10}(?:%s))' % tldcat)
 
-scrape_types = [
+scrape_types = [  # type: ignore
     ('hash:md5', r'(?=(?:[^A-Za-z0-9]|^)([A-Fa-f0-9]{32})(?:[^A-Za-z0-9]|$))', {}),
     ('hash:sha1', r'(?=(?:[^A-Za-z0-9]|^)([A-Fa-f0-9]{40})(?:[^A-Za-z0-9]|$))', {}),
     ('hash:sha256', r'(?=(?:[^A-Za-z0-9]|^)([A-Fa-f0-9]{64})(?:[^A-Za-z0-9]|$))', {}),
@@ -36,7 +36,7 @@ def scrape(text, ptype=None):
         (str, str): Yield tuples of type, valu strings.
     '''
 
-    for ruletype, rule, info in scrape_types:
+    for ruletype, _, _ in scrape_types:
         if ptype and ptype != ruletype:
             continue
         regx = regexes.get(ruletype)
