@@ -174,7 +174,8 @@ reqValidPkgdef = s_config.getJsValidator({
             'type': 'object',
             'properties': {
                 'name': {'type': 'string'},
-                'storm': {'type': 'string'}
+                'storm': {'type': 'string'},
+                'modconf': {'type': 'object'},
             },
             'additionalProperties': True,
             'required': ['name', 'storm']
@@ -621,6 +622,8 @@ stormcmds = (
         'cmdargs': (
             ('query', {'help': 'Query for the cron job to execute.'}),
             ('--minute', {'help': 'Minute value for job or recurrence period.'}),
+            ('--name', {'help': 'An optional name for the cron job.'}),
+            ('--doc', {'help': 'An optional doc string for the cron job.'}),
             ('--hour', {'help': 'Hour value for job or recurrence period.'}),
             ('--day', {'help': 'Day value for job or recurrence period.'}),
             ('--month', {'help': 'Month value for job or recurrence period.'}),
@@ -642,6 +645,9 @@ stormcmds = (
                                   monthly=$cmdopts.monthly,
                                   yearly=$cmdopts.yearly)
 
+            if $cmdopts.doc { $cron.set(doc, $cmdopts.doc) }
+            if $cmdopts.name { $cron.set(name, $cmdopts.name) }
+
             $lib.print("Created cron job: {iden}", iden=$cron.iden)
         ''',
     },
@@ -888,7 +894,7 @@ class DmonManager(s_base.Base):
         if not self.enabled:
             return
         await self._stopAllDmons()
-        await asyncio.sleep(0)
+        self.enabled = False
 
     # TODO write enable/disable APIS.
     # 1. Set dmon.status to 'disabled'
@@ -1593,7 +1599,9 @@ class Cmd:
 
     Notes:
         Python Cmd implementers may override the ``forms`` attribute with a dictionary to provide information
-        about Synapse forms which are possible input and output nodes that a Cmd may recognize.
+        about Synapse forms which are possible input and output nodes that a Cmd may recognize. A list of
+        (key, form) tuples may also be added to provide information about forms which may have additional
+        nodedata added to them by the Cmd.
 
         Example:
 
@@ -1607,6 +1615,10 @@ class Cmd:
                     'output': (
                         'geo:place',
                     ),
+                    'nodedata': (
+                        ('foodata', 'inet:http:request'),
+                        ('bardata', 'inet:ipv4'),
+                    ),
                 }
 
     '''
@@ -1670,6 +1682,7 @@ class Cmd:
 
         inpt = cls.forms.get('input')
         outp = cls.forms.get('output')
+        nodedata = cls.forms.get('nodedata')
 
         if inpt:
             props['input'] = tuple(inpt)
@@ -1677,6 +1690,9 @@ class Cmd:
         if outp:
             props['output'] = tuple(outp)
 
+        if nodedata:
+            props['nodedata'] = tuple(nodedata)
+
         if cls.svciden:
             props['svciden'] = cls.svciden
 
@@ -2280,6 +2296,8 @@ class GraphCmd(Cmd):
         pars.add_argument('--filter', default=[], action='append',
                           help='Specify a storm filter for all nodes. (must quote)')
 
+        pars.add_argument('--no-edges', default=False, action='store_true',
+                          help='Do not include light weight edges in the per-node output.')
         pars.add_argument('--form-pivot', default=[], nargs=2, action='append',
                           help='Specify a <form> <pivot> form specific pivot.')
         pars.add_argument('--form-filter', default=[], nargs=2, action='append',
@@ -2311,6 +2329,9 @@ class GraphCmd(Cmd):
 
         }
 
+        if self.opts.no_edges:
+            rules['edges'] = False
+
         for pivo in self.opts.pivot:
             rules['pivots'].append(pivo[1:-1])
 
@@ -2422,9 +2443,14 @@ class TreeCmd(Cmd):
                 async for item in recurse(nnode, npath):
                     yield item
 
-        async for node, path in genr:
-            async for nodepath in recurse(node, path):
-                yield nodepath
+        try:
+
+            async for node, path in genr:
+                async for nodepath in recurse(node, path):
+                    yield nodepath
+
+        except s_exc.RecursionLimitHit:
+            raise s_exc.StormRuntimeError(mesg='tree command exceeded maximum depth') from None
 
 class ScrapeCmd(Cmd):
     '''
@@ -2435,7 +2461,7 @@ class ScrapeCmd(Cmd):
         # Scrape properties from inbound nodes and create standalone nodes.
         inet:search:query | scrape
 
-        # Scrape properties from inbound nodes and make edge:refs to the scraped nodes.
+        # Scrape properties from inbound nodes and make refs light edges to the scraped nodes.
         inet:search:query | scrape --refs
 
         # Scrape only the :engine and :text props from the inbound nodes.
@@ -2451,9 +2477,9 @@ class ScrapeCmd(Cmd):
         pars = Cmd.getArgParser(self)
 
         pars.add_argument('--refs', '-r', default=False, action='store_true',
-                          help='Create edge:refs to any scraped nodes from the input node')
+                          help='Create refs light edges to any scraped nodes from the input node')
         pars.add_argument('--yield', dest='doyield', default=False, action='store_true',
-                          help='Include newly scraped nodes (or edge:refs if --refs) in the output')
+                          help='Include newly scraped nodes in the output')
         pars.add_argument('values', nargs='*',
                           help='Specific relative properties or variables to scrape')
         return pars
@@ -2498,14 +2524,13 @@ class ScrapeCmd(Cmd):
 
                 for form, valu in s_scrape.scrape(text):
 
-                    if refs:
-                        valu = (node.ndef, (form, valu))
-                        form = 'edge:refs'
-
                     try:
                         nnode = await node.snap.addNode(form, valu)
                         npath = path.fork(nnode)
 
+                        if refs:
+                            await node.addEdge('refs', nnode.iden())
+
                         if self.opts.doyield:
                             yield nnode, npath
 
