@@ -27,23 +27,20 @@ class PsModule(s_module.CoreModule):
                            ' resource, potentially during a specific period of time.'
                 }),
                 ('ps:contact', ('guid', {}), {
-                    'doc': 'A GUID for a contact info record',
+                    'doc': 'A GUID for a contact info record.',
                 }),
-
-                # FIXME add wireless elemements like NMEI and IMEI once modeled - pre 010 item
-
             ),
             'forms': (
                 ('ps:tokn', {}, ()),
                 ('ps:name', {}, (
                     ('sur', ('ps:tokn', {}), {
-                        'doc': 'The surname part of the name'
+                        'doc': 'The surname part of the name.'
                     }),
                     ('middle', ('ps:tokn', {}), {
-                        'doc': 'The middle name part of the name'
+                        'doc': 'The middle name part of the name.'
                     }),
                     ('given', ('ps:tokn', {}), {
-                        'doc': 'The given name part of the name'
+                        'doc': 'The given name part of the name.'
                     }),
                 )),
                 ('ps:person', {}, (
@@ -54,19 +51,25 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The primary image of a person.'
                     }),
                     ('nick', ('inet:user', {}), {
-                        'doc': 'A username commonly used by the person',
+                        'doc': 'A username commonly used by the person.',
                     }),
                     ('name', ('ps:name', {}), {
                         'doc': 'The localized name for the person.',
                     }),
                     ('name:sur', ('ps:tokn', {}), {
-                        'doc': 'The surname of the person'
+                        'doc': 'The surname of the person.'
                     }),
                     ('name:middle', ('ps:tokn', {}), {
-                        'doc': 'The middle name of the person'
+                        'doc': 'The middle name of the person.'
                     }),
                     ('name:given', ('ps:tokn', {}), {
-                        'doc': 'The given name of the person'
+                        'doc': 'The given name of the person.'
+                    }),
+                    ('names', ('array', {'type': 'ps:name'}), {
+                        'doc': 'Variations of the name for the person.'
+                    }),
+                    ('nicks', ('array', {'type': 'inet:user'}), {
+                        'doc': 'Usernames used by the  person.'
                     }),
                 )),
                 ('ps:persona', {}, (
@@ -80,7 +83,7 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The primary image of a suspected person.'
                     }),
                     ('nick', ('inet:user', {}), {
-                        'doc': 'A username commonly used by the suspected person',
+                        'doc': 'A username commonly used by the suspected person.',
                     }),
                     ('name', ('ps:name', {}), {
                         'doc': 'The localized name for the suspected person.',
@@ -94,6 +97,12 @@ class PsModule(s_module.CoreModule):
                     ('name:given', ('ps:tokn', {}), {
                         'doc': 'The given name of the suspected person.'
                     }),
+                    ('names', ('array', {'type': 'ps:name'}), {
+                        'doc': 'Variations of the name for a persona.'
+                    }),
+                    ('nicks', ('array', {'type': 'inet:user'}), {
+                        'doc': 'Usernames used by the persona.'
+                    }),
                 )),
                 ('ps:person:has', {}, (
                     ('person', ('ps:person', {}), {
@@ -134,7 +143,7 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The ps:person GUID which owns this contact.',
                     }),
                     ('name', ('ps:name', {}), {
-                        'doc': 'The person name listed for the contact',
+                        'doc': 'The person name listed for the contact.',
                     }),
                     ('title', ('str', {'lower': True, 'strip': True}), {
                         'doc': 'The job/org title listed for this contact.',
@@ -169,8 +178,11 @@ class PsModule(s_module.CoreModule):
                     ('address', ('geo:address', {}), {
                         'doc': 'The street address listed for the contact.',
                     }),
+                    ('place', ('geo:place', {}), {
+                        'doc': 'The place associated with this contact.',
+                    }),
                     ('phone', ('tel:phone', {}), {
-                        'doc': 'The main phone number for this contact',
+                        'doc': 'The main phone number for this contact.',
                     }),
                     ('phone:fax', ('tel:phone', {}), {
                         'doc': 'The fax number for this contact.',
