@@ -400,6 +400,11 @@ class AstTest(s_test.SynTest):
             self.len(1, nodes)
             self.sorteq(nodes[0].tags, ('base', 'base.tag1', 'base.tag1.foo', 'base.tag2'))
 
+            q = 'test:str $var=(11) [+#base.$var]'
+            nodes = await core.nodes(q)
+            self.len(1, nodes)
+            self.sorteq(nodes[0].tags, ('base', 'base.11', 'base.tag1', 'base.tag1.foo', 'base.tag2'))
+
     async def test_ast_var_in_deref(self):
 
         async with self.getTestCore() as core:
@@ -538,6 +543,13 @@ class AstTest(s_test.SynTest):
             self.len(1, nodes)
             self.eq('geo:nloc', nodes[0].ndef[0])
 
+    async def test_ast_pivot(self):
+        # a general purpose pivot test. come on in!
+        async with self.getTestCore() as core:
+            self.len(0, await core.nodes('[ inet:ipv4=1.2.3.4 ] :asn -> *'))
+            self.len(0, await core.nodes('[ inet:ipv4=1.2.3.4 ] :foo -> *'))
+            self.len(0, await core.nodes('[ inet:ipv4=1.2.3.4 ] :asn -> inet:asn'))
+
     async def test_ast_lift_filt_array(self):
 
         async with self.getTestCore() as core:
@@ -743,6 +755,38 @@ class AstTest(s_test.SynTest):
             with self.raises(s_exc.NoSuchName):
                 nodes = await core.nodes('test.nodes')
 
+            visi = await core.auth.addUser('visi')
+
+            async with core.getLocalProxy(user='visi') as asvisi:
+
+                # Test permissions
+                msgs = await s_test.alist(asvisi.storm('$lib.pkg.del(stormpkg)'))
+                errs = [m for m in msgs if m[0] == 'err']
+                self.len(1, errs)
+                self.eq(errs[0][1][0], 'AuthDeny')
+
+                await core.addUserRule(visi.iden, (True, ('pkg', 'del')))
+
+                await s_test.alist(asvisi.storm('$lib.pkg.del(stormpkg)'))
+
+                mesgs = await core.stormlist('pkg.list')
+                print_str = '\n'.join([m[1].get('mesg') for m in mesgs if m[0] == 'print'])
+                self.notin('stormpkg', print_str)
+
+                msgs = await s_test.alist(asvisi.storm('$lib.pkg.add($pkg)',
+                                                       opts={'vars': {'pkg': stormpkg}}))
+                errs = [m for m in msgs if m[0] == 'err']
+                self.len(1, errs)
+                self.eq(errs[0][1][0], 'AuthDeny')
+
+                await core.addUserRule(visi.iden, (True, ('pkg', 'add')))
+
+                await s_test.alist(asvisi.storm('$lib.pkg.add($pkg)',
+                                                opts={'vars': {'pkg': stormpkg}}))
+
+                msgs = await core.stormlist('pkg.list')
+                self.stormIsInPrint('stormpkg', msgs)
+
     async def test_function(self):
         async with self.getTestCore() as core:
             await core.addStormPkg(foo_stormpkg)
@@ -1473,3 +1517,7 @@ class AstTest(s_test.SynTest):
             self.len(1, nodes)
             self.len(1, nodes[0][1]['path']['edges'])
             self.eq('refs', nodes[0][1]['path']['edges'][0][1]['verb'])
+
+            msgs = await core.stormlist('media:news | graph --no-edges')
+            nodes = [m[1] for m in msgs if m[0] == 'node']
+            self.len(0, nodes[0][1]['path']['edges'])
