@@ -391,8 +391,18 @@ class CellTest(s_t_utils.SynTest):
                 todo = s_common.todo('stream', doraise=True)
                 await self.agenraises(s_exc.BadTime, await prox.dyncall('self', todo))
 
-    async def test_cell_nexuschanges(self):
+    async def test_cell_promote(self):
+
         with self.getTestDir() as dirn:
+            async with await s_cell.Cell.anit(dirn) as cell:
+                async with cell.getLocalProxy() as proxy:
+                    with self.raises(s_exc.BadConfValu):
+                        await proxy.promote()
+
+    async def test_cell_nexuschanges(self):
+
+        with self.getTestDir() as dirn:
+
             dir0 = s_common.genpath(dirn, 'cell00')
             dir1 = s_common.genpath(dirn, 'cell01')
 
@@ -407,13 +417,20 @@ class CellTest(s_t_utils.SynTest):
                         break
                 return yielded, retn
 
-            conf = {'nexslog:en': True}
+            conf = {
+                'nexslog:en': True,
+                'nexslog:async': True,
+                'dmon:listen': 'tcp://127.0.0.1:0/',
+                'https:port': 0,
+            }
             async with await s_cell.Cell.anit(dir0, conf=conf) as cell00, \
                     cell00.getLocalProxy() as prox00:
 
+                self.true(cell00.nexsroot.map_async)
                 self.true(cell00.nexsroot.donexslog)
 
                 await prox00.addUser('test')
+                self.true(await prox00.getNexsIndx() > 0)
 
                 # We should have a set of auth:auth changes to find
                 task = cell00.schedCoro(coro(prox00, 0))
@@ -496,3 +513,77 @@ class CellTest(s_t_utils.SynTest):
             async with core.getLocalProxy() as proxy:
                 self.eq((), await proxy.getHiveKeys(('lulz',)))
                 self.eq((('bar', 10), ('baz', 30)), await proxy.getHiveKeys(('foo',)))
+
+    async def test_cell_confprint(self):
+
+        with self.withSetLoggingMock():
+
+            with self.getTestDir() as dirn:
+
+                conf = {
+                    'dmon:listen': 'tcp://127.0.0.1:0',
+                    'https:port': 0,
+                }
+                s_common.yamlsave(conf, dirn, 'cell.yaml')
+
+                outp = self.getTestOutp()
+                async with await s_cell.Cell.initFromArgv([dirn], outp=outp) as cell:
+                    outp.expect('...cell API (telepath): tcp://127.0.0.1:0')
+                    outp.expect('...cell API (https): 0')
+
+                conf = {
+                    'dmon:listen': 'tcp://127.0.0.1:0',
+                    'https:port': None,
+                }
+                s_common.yamlsave(conf, dirn, 'cell.yaml')
+
+                outp = self.getTestOutp()
+                async with await s_cell.Cell.initFromArgv([dirn], outp=outp) as cell:
+                    outp.expect('...cell API (telepath): tcp://127.0.0.1:0')
+                    outp.expect('...cell API (https): disabled')
+
+    async def test_cell_backup(self):
+
+        async with  self.getTestCore() as core:
+            with self.raises(s_exc.NeedConfValu):
+                await core.runBackup()
+            with self.raises(s_exc.NeedConfValu):
+                await core.getBackups()
+            with self.raises(s_exc.NeedConfValu):
+                await core.delBackup('foo')
+
+        with self.getTestDir() as dirn:
+            s_common.yamlsave({'backup:dir': dirn}, dirn, 'cell.yaml')
+            with self.raises(s_exc.BadConfValu):
+                async with self.getTestCore(dirn=dirn) as core:
+                    pass
+
+        with self.getTestDir() as dirn:
+
+            backdirn = os.path.join(dirn, 'backups')
+            coredirn = os.path.join(dirn, 'cortex')
+
+            conf = {'backup:dir': backdirn}
+            s_common.yamlsave(conf, coredirn, 'cell.yaml')
+
+            async with self.getTestCore(dirn=coredirn) as core:
+
+                async with core.getLocalProxy() as proxy:
+
+                    with self.raises(s_exc.BadArg):
+                        await proxy.runBackup('../woot')
+
+                    name = await proxy.runBackup()
+                    self.eq((name,), await proxy.getBackups())
+                    await proxy.delBackup(name)
+                    self.eq((), await proxy.getBackups())
+                    name = await proxy.runBackup(name='foo/bar')
+
+                    with self.raises(s_exc.BadArg):
+                        await proxy.delBackup(name='foo')
+
+                    self.true(os.path.isdir(os.path.join(backdirn, 'foo', 'bar')))
+                    self.eq(('foo/bar',), await proxy.getBackups())
+
+                    with self.raises(s_exc.BadArg):
+                        await proxy.runBackup(name='foo/bar')
