@@ -1,3 +1,4 @@
+import os
 import math
 import asyncio
 import contextlib
@@ -6,6 +7,7 @@ import synapse.exc as s_exc
 import synapse.common as s_common
 import synapse.telepath as s_telepath
 
+import synapse.lib.time as s_time
 import synapse.lib.layer as s_layer
 import synapse.lib.msgpack as s_msgpack
 
@@ -503,7 +505,7 @@ class LayerTest(s_t_utils.SynTest):
             # Get all but the first splice
             await self.agenlen(25, layr.splices((0, 0, 1)))
 
-            await self.agenlen(4, layr.splicesBack((1, 0, 0)))
+            await self.agenlen(4, layr.splicesBack((2, 0, 0)))
 
             # Make sure we still get two splices when
             # offset is not at the beginning of a nodeedit
@@ -677,6 +679,78 @@ class LayerTest(s_t_utils.SynTest):
             nodeedits_out = await layr.storNodeEdits(nodeedits, {})
             self.notin('faz.baz', nodeedits_out[0][1]['tags'])
 
+    async def test_layer_nodeedits_created(self):
+
+        async with self.getTestCore() as core:
+
+            nodes = await core.nodes('[ test:int=1 :loc=us ]')
+            created00 = nodes[0].get('.created')
+
+            layr = core.getLayer()
+
+            editlist00 = [nes async for nes in layr.iterLayerNodeEdits()]
+
+            await core.nodes('test:int=1 | delnode')
+            self.len(0, await core.nodes('test:int'))
+
+            # Simulate a nexus edit list (no .created)
+            nexslist00 = [(ne[0], ne[1], [e for e in ne[2] if e[1][0] != '.created']) for ne in editlist00]
+
+            # meta used for .created
+            await asyncio.sleep(0.01)
+            await layr.storNodeEdits(nexslist00, {'time': created00})
+
+            nodes = await core.nodes('test:int')
+            self.len(1, nodes)
+
+            self.eq(created00, nodes[0].get('.created'))
+
+            await core.nodes('test:int=1 | delnode')
+            self.len(0, await core.nodes('test:int'))
+
+            # If meta is not specified .created gets populated to now
+            await asyncio.sleep(0.01)
+            await layr.storNodeEdits(nexslist00, None)
+
+            nodes = await core.nodes('test:int')
+            self.len(1, nodes)
+
+            created01 = nodes[0].get('.created')
+            self.gt(created01, created00)
+
+            # edits with the same node has the same .created
+            await asyncio.sleep(0.01)
+            nodes = await core.nodes('[ test:int=1 ]')
+            self.eq(created01, nodes[0].get('.created'))
+
+            nodes = await core.nodes('[ test:int=1 :loc=us +#foo]')
+            self.eq(created01, nodes[0].get('.created'))
+
+            await core.nodes('test:int=1 | delnode')
+            self.len(0, await core.nodes('test:int'))
+
+            # Tests for behavior of storing nodeedits directly prior to using meta (i.e. meta['time'] != .created)
+            # .created is a MINTIME therefore earlier value wins, which is typically meta
+            created02 = s_time.parse('1990-10-10 12:30')
+            await layr.storNodeEdits(editlist00, {'time': created02})
+
+            nodes = await core.nodes('test:int')
+            self.len(1, nodes)
+
+            self.eq(created02, nodes[0].get('.created'))
+
+            await core.nodes('test:int=1 | delnode')
+            self.len(0, await core.nodes('test:int'))
+
+            # meta could be after .created for manual store operations
+            created03 = s_time.parse('2050-10-10 12:30')
+            await layr.storNodeEdits(editlist00, {'time': created03})
+
+            nodes = await core.nodes('test:int')
+            self.len(1, nodes)
+
+            self.eq(created00, nodes[0].get('.created'))
+
     async def test_layer_nodeedits(self):
 
         async with self.getTestCoreAndProxy() as (core0, prox0):
@@ -689,15 +763,12 @@ class LayerTest(s_t_utils.SynTest):
 
             nodelist0 = [node.pack() for node in nodelist0]
 
-            count = 0
             editlist = []
 
-            layr = core0.getLayer(None)
-            necount = layr.nodeeditlog.index()
-            async for _, nodeedits in prox0.syncLayerNodeEdits(0):
+            layr = core0.getLayer()
+            async for offs, nodeedits in prox0.syncLayerNodeEdits(0):
                 editlist.append(nodeedits)
-                count += 1
-                if count == necount:
+                if offs == layr.nodeeditlog.index() - 1:
                     break
 
             async with self.getTestCore() as core1:
@@ -756,33 +827,27 @@ class LayerTest(s_t_utils.SynTest):
             # add node - buid:form exists
             nodes = await core.nodes('[ inet:ipv4=1.2.3.4 :loc=us ]')
             buid0 = nodes[0].buid
-            fenc = layr00.layrslab.get(buid0 + b'\x09', db=layr00.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr00.getNodeForm(buid0))
 
             # add edge and nodedata
             nodes = await core.nodes('[ inet:ipv4=2.3.4.5 ]')
             buid1 = nodes[0].buid
-            fenc = layr00.layrslab.get(buid1 + b'\x09', db=layr00.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr00.getNodeForm(buid1))
 
             await core.nodes('inet:ipv4=1.2.3.4 [ +(refs)> {inet:ipv4=2.3.4.5} ] $node.data.set(spam, ham)')
-            fenc = layr00.layrslab.get(buid0 + b'\x09', db=layr00.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr00.getNodeForm(buid0))
 
             # remove edge, map still exists
             await core.nodes('inet:ipv4=1.2.3.4 [ -(refs)> {inet:ipv4=2.3.4.5} ]')
-            fenc = layr00.layrslab.get(buid0 + b'\x09', db=layr00.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr00.getNodeForm(buid0))
 
             # remove nodedata, map still exists
             await core.nodes('inet:ipv4=1.2.3.4 $node.data.pop(spam)')
-            fenc = layr00.layrslab.get(buid0 + b'\x09', db=layr00.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr00.getNodeForm(buid0))
 
             # delete node - buid:form removed
             await core.nodes('inet:ipv4=1.2.3.4 | delnode')
-            fenc = layr00.layrslab.get(buid0 + b'\x09', db=layr00.bybuid)
-            self.none(fenc)
+            self.none(await layr00.getNodeForm(buid0))
 
             await core.nodes('[ inet:ipv4=5.6.7.8 ]')
 
@@ -794,41 +859,34 @@ class LayerTest(s_t_utils.SynTest):
             await alist(view01.eval('[ inet:ipv4=6.7.8.9 ]'))
 
             # buid:form for a node in child doesn't exist
-            fenc = layr01.layrslab.get(buid1 + b'\x09', db=layr01.bybuid)
-            self.none(fenc)
+            self.none(await layr01.getNodeForm(buid1))
 
             # add prop, buid:form map exists
             nodes = await alist(view01.eval('inet:ipv4=2.3.4.5 [ :loc=ru ]'))
             self.len(1, nodes)
-            fenc = layr01.layrslab.get(buid1 + b'\x09', db=layr01.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr01.getNodeForm(buid1))
 
             # add nodedata and edge
             await alist(view01.eval('inet:ipv4=2.3.4.5 [ +(refs)> {inet:ipv4=6.7.8.9} ] $node.data.set(faz, baz)'))
 
             # remove prop, map still exists due to nodedata
             await alist(view01.eval('inet:ipv4=2.3.4.5 [ -:loc ]'))
-            fenc = layr01.layrslab.get(buid1 + b'\x09', db=layr01.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr01.getNodeForm(buid1))
 
             # remove nodedata, map still exists due to edge
             await alist(view01.eval('inet:ipv4=2.3.4.5 $node.data.pop(faz)'))
-            fenc = layr01.layrslab.get(buid1 + b'\x09', db=layr01.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr01.getNodeForm(buid1))
 
             # remove edge, map is deleted
             await alist(view01.eval('inet:ipv4=2.3.4.5 [ -(refs)> {inet:ipv4=6.7.8.9} ]'))
-            fenc = layr01.layrslab.get(buid1 + b'\x09', db=layr01.bybuid)
-            self.none(fenc)
+            self.none(await layr01.getNodeForm(buid1))
 
             # edges between two nodes in parent
             await alist(view01.eval('inet:ipv4=2.3.4.5 [ +(refs)> {inet:ipv4=5.6.7.8} ]'))
-            fenc = layr01.layrslab.get(buid1 + b'\x09', db=layr01.bybuid)
-            self.eq('inet:ipv4', fenc.decode())
+            self.eq('inet:ipv4', await layr01.getNodeForm(buid1))
 
             await alist(view01.eval('inet:ipv4=2.3.4.5 [ -(refs)> {inet:ipv4=5.6.7.8} ]'))
-            fenc = layr01.layrslab.get(buid1 + b'\x09', db=layr01.bybuid)
-            self.none(fenc)
+            self.none(await layr01.getNodeForm(buid1))
 
     async def test_layer(self):
 
@@ -850,6 +908,18 @@ class LayerTest(s_t_utils.SynTest):
             self.false(await layr.hasTagProp('score'))
             nodes = await core.nodes('[test:str=bar +#test:score=100]')
 
+    async def test_layer_waitForHot(self):
+
+        async with self.getTestCore() as core:
+            layr = core.getLayer()
+
+            await asyncio.wait_for(layr.waitForHot(), timeout=1.0)
+
+        conf = {'layers:lockmemory': True}
+        async with self.getTestCore(conf=conf) as core:
+            layr = core.getLayer()
+            await asyncio.wait_for(layr.waitForHot(), timeout=1.0)
+
     async def test_layer_no_extra_logging(self):
 
         async with self.getTestCore() as core:
@@ -872,3 +942,55 @@ class LayerTest(s_t_utils.SynTest):
             await core.nodes('.created | delnode --force')
             nodes = await core.nodes('.created')
             self.len(0, nodes)
+
+    async def test_layer_flat_edits(self):
+        nodeedits = (
+            (b'asdf', 'test:junk', (
+                (s_layer.EDIT_NODE_ADD, (10, s_layer.STOR_TYPE_U64), (
+                    (b'qwer', 'test:junk', (
+                        (s_layer.EDIT_NODE_ADD, (11, s_layer.STOR_TYPE_U64), ()),
+                    )),
+                )),
+            )),
+        )
+        self.len(2, s_layer.getFlatEdits(nodeedits))
+
+    async def test_layer_clone(self):
+
+        async with self.getTestCoreAndProxy() as (core, prox):
+
+            layr = core.getLayer()
+            self.isin(f'Layer (Layer): {layr.iden}', str(layr))
+
+            nodes = await core.nodes('[test:str=foo .seen=(2015, 2016)]')
+            buid = nodes[0].buid
+
+            self.eq('foo', await layr.getNodeValu(buid))
+            self.eq((1420070400000, 1451606400000), await layr.getNodeValu(buid, '.seen'))
+
+            s_common.gendir(layr.dirn, 'adir')
+
+            copylayrinfo = await core.cloneLayer(layr.iden)
+            self.len(2, core.layers)
+
+            copylayr = core.getLayer(copylayrinfo.get('iden'))
+            self.isin(f'Layer (Layer): {copylayr.iden}', str(copylayr))
+            self.ne(layr.iden, copylayr.iden)
+
+            self.eq('foo', await copylayr.getNodeValu(buid))
+            self.eq((1420070400000, 1451606400000), await copylayr.getNodeValu(buid, '.seen'))
+
+            cdir = s_common.gendir(copylayr.dirn, 'adir')
+            self.true(os.path.exists(cdir))
+
+            await self.asyncraises(s_exc.NoSuchLayer, prox.cloneLayer('newp'))
+
+            self.false(layr.readonly)
+
+            # Test overriding layer config values
+            ldef = {'readonly': True}
+            readlayrinfo = await core.cloneLayer(layr.iden, ldef)
+            self.len(3, core.layers)
+
+            readlayr = core.getLayer(readlayrinfo.get('iden'))
+            self.true(readlayr.readonly)
