@@ -7,6 +7,7 @@ import synapse.common as s_common
 
 from unittest.mock import patch
 
+import synapse.lib.base as s_base
 import synapse.lib.const as s_const
 import synapse.lib.lmdbslab as s_lmdbslab
 import synapse.lib.thisplat as s_thisplat
@@ -32,7 +33,6 @@ class LmdbSlabTest(s_t_utils.SynTest):
         with self.getTestDir() as dirn:
 
             path = os.path.join(dirn, 'test.lmdb')
-
             async with await s_lmdbslab.Slab.anit(path) as slab:
 
                 testdb = slab.initdb('test')
@@ -40,16 +40,19 @@ class LmdbSlabTest(s_t_utils.SynTest):
                 editdb = slab.initdb('edit')
 
                 self.eq((), list(slab.scanKeys(db=testdb)))
+                self.eq((), list(slab.scanByDupsBack(b'asdf', db=dupsdb)))
 
                 slab.put(b'hehe', b'haha', db=dupsdb)
                 slab.put(b'hehe', b'lolz', db=dupsdb)
                 slab.put(b'hoho', b'asdf', db=dupsdb)
 
+                self.eq((), list(slab.scanByDupsBack(b'h\x00', db=dupsdb)))
+
                 slab.put(b'hehe', b'haha', db=testdb)
                 slab.put(b'hoho', b'haha', db=testdb)
 
                 testgenr = slab.scanKeys(db=testdb)
-                dupsgenr = slab.scanKeys(db=testdb)
+                dupsgenr = slab.scanKeys(db=dupsdb)
 
                 testlist = [next(testgenr)]
                 dupslist = [next(dupsgenr)]
@@ -63,7 +66,7 @@ class LmdbSlabTest(s_t_utils.SynTest):
                 dupslist.extend(dupsgenr)
 
                 self.eq(testlist, (b'hehe', b'hoho'))
-                self.eq(dupslist, (b'hehe', b'hoho'))
+                self.eq(dupslist, (b'hehe', b'hehe', b'hoho'))
 
                 # now lets delete the key we're on
                 testgenr = slab.scanKeys(db=testdb)
@@ -147,6 +150,8 @@ class LmdbSlabTest(s_t_utils.SynTest):
             self.false(slab.rangeexists(b'\x01\x04', b'\x01\x05', db=foo))
 
             # backwards scan tests
+            items = list(slab.scanByRangeBack(b'\x00', db=foo))
+            self.eq(items, ())
 
             items = list(slab.scanByPrefBack(b'\x00', db=foo))
             self.eq(items, ((b'\x00\x02', b'haha'), (b'\x00\x01', b'hehe')))
@@ -269,6 +274,28 @@ class LmdbSlabTest(s_t_utils.SynTest):
             self.raises(s_exc.IsFini, next, scan)
             self.raises(s_exc.IsFini, next, scanback)
 
+    async def test_lmdbslab_max_replay(self):
+        with self.getTestDir() as dirn:
+            path = os.path.join(dirn, 'test.lmdb')
+
+            my_maxlen = 100
+
+            # Make sure that we don't confuse the periodic commit with the max replay log commit
+
+            with patch('synapse.lib.lmdbslab.Slab.COMMIT_PERIOD', 10):
+                async with await s_lmdbslab.Slab.anit(path, map_size=100000, max_replay_log=my_maxlen) as slab:
+                    foo = slab.initdb('foo', dupsort=True)
+                    byts = b'\x00' * 256
+
+                    waiter = s_base.Waiter(slab, 1, 'commit')
+
+                    for i in range(150):
+                        slab.put(b'\xff\xff\xff\xff' + s_common.guid(i).encode('utf8'), byts, db=foo)
+
+                    self.true(slab.syncevnt.is_set())
+
+                    self.len(1, await waiter.wait(timeout=1))
+
     async def test_lmdbslab_maxsize(self):
         with self.getTestDir() as dirn:
             path = os.path.join(dirn, 'test.lmdb')
@@ -299,6 +326,7 @@ class LmdbSlabTest(s_t_utils.SynTest):
 
                 foo = slab.initdb('foo', dupsort=True)
                 foo2 = slab.initdb('foo2', dupsort=False)
+                bar = slab.initdb('bar', dupsort=True)
 
                 multikey = b'\xff\xff\xff\xfe' + s_common.guid(2000).encode('utf8')
 
@@ -307,11 +335,11 @@ class LmdbSlabTest(s_t_utils.SynTest):
                     slab.put(multikey, s_common.int64en(i), dupdata=True, db=foo)
                     slab.put(s_common.int64en(i), byts, db=foo2)
 
-                iter = slab.scanByDups(multikey, db=foo)
+                iter1 = slab.scanByDups(multikey, db=foo)
                 iter2 = slab.scanByFull(db=foo2)
 
                 for _ in range(6):
-                    next(iter)
+                    next(iter1)
                     next(iter2)
 
                 iterback = slab.scanByDupsBack(multikey, db=foo)
@@ -340,10 +368,10 @@ class LmdbSlabTest(s_t_utils.SynTest):
 
                 slab.forcecommit()
 
-                self.raises(StopIteration, next, iter)
+                self.raises(StopIteration, next, iter1)
                 self.raises(StopIteration, next, iter2)
-                self.eq(5, sum(1 for _ in iterback))
-                self.eq(5, sum(1 for _ in iterback2))
+                self.len(5, iterback)
+                self.len(5, iterback2)
 
                 # Delete all the keys in front of a backwards scan
                 for i in range(4):
@@ -360,6 +388,22 @@ class LmdbSlabTest(s_t_utils.SynTest):
                 self.raises(StopIteration, next, iterback5)
                 self.raises(StopIteration, next, iterback6)
 
+                slab.put(b'\x00', b'asdf', dupdata=True, db=bar)
+                slab.put(b'\x01', b'qwer', dupdata=True, db=bar)
+                iterback = slab.scanByRangeBack(b'\x00', db=bar)
+                self.eq((b'\x00', b'asdf'), next(iterback))
+                slab.delete(b'\x00', b'asdf', db=bar)
+                slab.forcecommit()
+                self.raises(StopIteration, next, iterback)
+
+                # range scan where we delete the entry we're on
+                # and it's the only thing in the slab.
+                iterrange = slab.scanByRange(b'\x00', db=bar)
+                self.eq((b'\x01', b'qwer'), next(iterrange))
+                slab.delete(b'\x01', b'qwer', db=bar)
+                slab.forcecommit()
+                self.raises(StopIteration, next, iterrange)
+
     async def test_lmdbslab_scanbump2(self):
 
         with self.getTestDir() as dirn:
@@ -532,6 +576,13 @@ class LmdbSlabTest(s_t_utils.SynTest):
                 self.eq((b'1', b'1'), next(it))
                 self.raises(StopIteration, next, it)
 
+    async def test_lmdbslab_count_empty(self):
+
+        with self.getTestDir() as dirn:
+            path = os.path.join(dirn, 'test.lmdb')
+            async with await s_lmdbslab.Slab.anit(path, map_size=100000, growsize=10000) as slab:
+                self.eq(0, await slab.countByPref(b'asdf'))
+
     async def test_lmdbslab_grow(self):
 
         with self.getTestDir() as dirn:
@@ -1157,6 +1208,50 @@ class LmdbSlabTest(s_t_utils.SynTest):
                 # Can't re-open while already open
                 await self.asyncraises(s_exc.SlabAlreadyOpen, s_lmdbslab.Slab.anit(path))
 
+    async def test_lmdbslab_copyslab(self):
+
+        with self.getTestDir() as dirn:
+
+            path = os.path.join(dirn, 'test.lmdb')
+            copypath = os.path.join(dirn, 'copy.lmdb')
+
+            async with await s_lmdbslab.Slab.anit(path) as slab:
+                foo = slab.initdb('foo')
+                slab.put(b'\x00\x01', b'hehe', db=foo)
+
+                await slab.copyslab(copypath)
+
+                self.true(pathlib.Path(copypath).with_suffix('.opts.yaml').exists())
+
+                async with await s_lmdbslab.Slab.anit(copypath) as slabcopy:
+                    foo = slabcopy.initdb('foo')
+                    self.eq(b'hehe', slabcopy.get(b'\x00\x01', db=foo))
+
+                await self.asyncraises(s_exc.DataAlreadyExists, slab.copyslab(copypath))
+
+    async def test_lmdbslab_statinfo(self):
+
+        with self.getTestDir() as dirn:
+
+            path = os.path.join(dirn, 'test.lmdb')
+
+            async with await s_lmdbslab.Slab.anit(path) as slab:
+
+                foo = slab.initdb('foo')
+
+                slab.put(b'\x00\x01', b'hehe', db=foo)
+                slab.put(b'\x00\x02', b'haha', db=foo)
+                await slab.sync()
+
+                stats = slab.statinfo()
+
+                self.false(stats['locking_memory'])
+                self.false(stats['prefaulting'])
+
+                commitstats = stats['commitstats']
+                self.len(2, commitstats)
+                self.eq(2, commitstats[-1][1])
+
 class LmdbSlabMemLockTest(s_t_utils.SynTest):
 
     async def test_lmdbslabmemlock(self):
