@@ -117,7 +117,16 @@ class RealService(s_stormsvc.StormSvc):
             'name': 'foo',
             'version': (0, 0, 1),
             'modules': (
-                {'name': 'foo.bar', 'storm': 'function asdf(x, y) { return ($($x + $y)) }'},
+                {'name': 'foo.bar',
+                 'storm': '''
+                 function asdf(x, y) { return ($($x + $y)) }
+                 function printmodconf() {
+                     for ($k, $v) in $modconf { $lib.print('{k}={v}', k=$k, v=$v) }
+                     return ( $lib.true )
+                 }
+                 ''',
+                 'modconf': {'key': 'valu'},
+                 },
             ),
             'commands': (
                 {
@@ -277,6 +286,9 @@ class StormvarService(s_cell.CellApi, s_stormsvc.StormSvc):
                     'forms': {
                         'input': ('test:str', 'test:int'),
                         'output': ('test:comp', 'inet:ipv4'),
+                        'nodedata': (
+                            ('foo', 'inet:ipv4'),
+                        ),
                     },
                     'storm': '''
                     $fooz = $cmdopts.name
@@ -353,8 +365,9 @@ class StormSvcTest(s_test.SynTest):
                 await core.nodes('$lib.service.wait(fake)')
 
                 core.svcsbyname['fake'].proxy._t_conf['timeout'] = 0.1
+                proxy = core.svcsbyname['fake'].proxy._t_proxy
 
-            await core.svcsbyname['fake'].proxy._t_proxy.waitfini(6)
+            self.true(await proxy.waitfini(6))
 
             with self.raises(s_exc.StormRuntimeError):
                 await core.nodes('[ inet:ipv4=6.6.6.6 ] | ohhai')
@@ -524,6 +537,11 @@ class StormSvcTest(s_test.SynTest):
                     nodes = await core.nodes('lifter')
                     self.len(1, nodes)
 
+                    # modconf data is available to commands
+                    msgs = await core.stormlist('$real_lib = $lib.import("foo.bar") $real_lib.printmodconf()')
+                    self.stormIsInPrint(f'svciden={iden}', msgs)
+                    self.stormIsInPrint('key=valu', msgs)
+
                 async with await s_cortex.Cortex.anit(dirn) as core:
 
                     nodes = await core.nodes('$lib.service.wait(fake)')
@@ -733,8 +751,6 @@ class StormSvcTest(s_test.SynTest):
 
                 async with self.getTestCore(dirn=path00) as core00:
 
-                    self.false(core00.mirror)
-
                     url = core00.getLocalUrl()
 
                     conf = {'mirror': url}
@@ -742,8 +758,6 @@ class StormSvcTest(s_test.SynTest):
 
                         await core01.sync()
 
-                        self.true(core01.mirror)
-
                         # Add a storm service
                         await core01.nodes(f'service.add real {lurl}')
                         await core01.nodes('$lib.service.wait(real)')
