@@ -350,6 +350,13 @@ class TypesTest(s_t_utils.SynTest):
         self.eq((1448150400000, 1451606400000), ival.norm(('2016', '-40 days'))[0])
         self.eq((1447891200000, 1451347200000), ival.norm(('2016-3days', '-40 days   '))[0])
         self.eq((1451347200000, 0x7fffffffffffffff), ival.norm(('2016-3days', '?'))[0])
+        self.eq((1593576000000, 1593576000001), ival.norm('2020-07-04:00')[0])
+        self.eq((1594124993000, 1594124993001), ival.norm('2020-07-07T16:29:53+04:00')[0])
+        self.eq((1594153793000, 1594153793001), ival.norm('2020-07-07T16:29:53-04:00')[0])
+        self.eq((1594211393000, 1594211393001), ival.norm('20200707162953+04:00+1day')[0])
+        self.eq((1594038593000, 1594038593001), ival.norm('20200707162953+04:00-1day')[0])
+        self.eq((1594240193000, 1594240193001), ival.norm('20200707162953-04:00+1day')[0])
+        self.eq((1594067393000, 1594067393001), ival.norm('20200707162953-04:00-1day')[0])
 
         start = s_common.now() + s_time.oneday - 1
         end = ival.norm(('now', '+1day'))[0][1]
